==> BirthdayListing-1.2.zip: BirthdayListing/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Birthday Listing';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Thanks for using this module';
$lang['really_uninstall'] = 'Really? Are you sure you want to unsinstall this module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module gives an overview of the person that are celebrating their birthday. Samples of celebrities 
are included. One is able to set when a person has deceased.';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';
$lang['error'] = 'Error!';
$lang['firstpage'] = '<<';
$lang['lastpage'] = '>>';
$lang['nextpage'] = '>';
$lang['title_pagelimit'] = 'Max lines/page in back end';
$lang['pagename'] = 'Page';
$lang['prevpage'] = '<';
$lang['prompt_of'] = 'of';
$lang['unlimited'] = 'Unlimited';

$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['addbirthday'] = 'Add birthday';
$lang['addtemplate'] = 'Add template';
$land['admin_title'] = 'Birthday Listing Admin Panel';
$lang['admindescription'] = 'Listing of the various birthdays. Samples of celebrities 
are included. One is able to set when a person has deceased.';
$lang['age'] = 'Age';
$lang['apply'] = 'Apply';
$lang['areyousure'] = 'Are you sure';
$lang['birthdate'] = 'Date of birth';
$lang['birthdates'] = 'Birth dates';
$lang['birthdayadded'] = 'Birthday added';
$lang['birthdaydeleted'] = 'Birthday deleted';
$lang['birthdayindays'] = 'Birthdays in the next %s days';
$lang['birthdays'] = 'Birthdays';
$lang['birthdayupdated'] = 'Birthday updated';
$lang['createsamples'] = 'Create samples';
$lang['deceased'] = 'Deceased on';
$lang['deceaseddates'] = 'Date of death';
$lang['deletesamples'] = 'Delete samples';
$lang['deletetemplate'] = 'Delete template';
$lang['edittemplate'] = 'Change';
$lang['errortemplatenameexists'] = 'Template name already exists';
$lang['help_template'] = 'Available parms are:<br />
- {$datetext} - Header text;<br />
- {$itemcount} - Number of birthdays found;<br />
- {$nobirthdays} - Message that there are no birthdays;<br />
- {$entry->age} - Age of person;<br />
- {$entry->birthday|date_format:"%Y %m %d"} - The actual date of birth and a format example;<br />
- {$entry->deceased|date_format:"%Y %m %d"} - The date person died;<br />
- {$entry->name} - Name of person;<br />
- {$entry->withindays} - Days until birthday;<br />
- {$entry->rowclass} - Contains for uneven rows: row1 and for even rows: row2 (which can be used in stylesheet).
';
$lang['isdead'] = 'Person has deceased';
$lang['orderbymonthday'] = 'Order by month/day';
$lang['orderbyname'] = 'Order by name';
$lang['postinstall'] = 'Be sure to set "Use Birthday Listings" permissions to use this module!';
$lang['name'] = 'Name of person';
$lang['names'] = 'Names';
$lang['nobirthdays'] = 'No birthdays today';
$lang['nobirthindays'] = 'No birthdays in the next %s days';
$lang['nobodybirthday'] = 'That is a pitty, nobody is celebrating their birthday!';
$lang['nonamegiven'] = 'Name is mandatory';
$lang['optionsupdated'] = 'Options are saved';
$lang['samplehandlingcreated'] = 'Samples have been created';
$lang['samplehandlingdeleted'] = 'Samples have been deleted';
$lang['template'] = 'Template';
$lang['template_help'] = 'Help for this Template';
$lang['template_deleted'] = 'Template deleted';
$lang['templatename'] = 'Name of template';
$lang['templatenametext'] = 'Templates';
$lang['templates'] = 'Templates';
$lang['title_birthdays'] = 'Birthdays';
$lang['title_birthdaysfound'] = 'Birthdays found';
$lang['title_dateformat'] = 'Date format for date picker';
$lang['title_nobirthdaystext'] = 'Text for front end when no birthdays';
$lang['title_options'] = 'Options';
$lang['title_orderbackend'] = 'Which order to list persons in backend';
$lang['title_splitdateused'] = 'Use drop down on date entry?';
$lang['title_templates'] = 'Templates';
$lang['todaysbirthdates'] = 'Today\'s birthdays:';
$lang['todaybirthdays'] = 'Today, %s persons turned a year older.';
$lang['updatetemplatesuccess'] = 'Template succefully saved';

// Parameters
$lang['helpshowage'] = 'Set to \'1\' to show the age of the person.';
$lang['helpshowdeceased'] = 'Set to \'1\' to show deceased person(s).';
$lang['helpsummarytemplate'] = 'Override to a template. If not used, template Summary will be taken.';
$lang['helpwithindays'] = 'Period of time in days to look for coming birthdays. Not including this parameter will show 
only todays birthdays.';

$lang['help'] = '<h3>What Does This Do?</h3>
<p>Gives an overview of the persons that are celebrating their birthday.</p>
<h3>How Do I Use It</h3>
<p>Just enter the persons with their date of birth and death and put the following as content in a page or template:
 {cms_module module=birthdaylisting}. An example with all the parameters is: {cms_module module=birthdaylisting showdeceased=1 showage=1 withindays=30}
  in which all the birthdays in the comming 30 days are shown (names, age, birthday and date of decease).<br />
The dates that are shown in the back end are formatted based upon the user preferences. If not available, \'%d %B %Y\' will be used.</p>
<p>
You can define the format of how you enter the birthday and date deceased via the options.
</p>
<p>Sample data can be prepared via the options tab. At least 5 days of each month will have a birthday of known and less known 
persons. When you enter birthdays yourself and after that you want to delete the sample data, your manually entered dates will remain while only 
the sample dates are removed.</p>
<p>Note: you might find odd dates when sample data has been loaded. This is because the regularly used command (strftime) doesn\'t work 
correctly for dates dat are before 1900. Sorry for this. An example of this error might be seen
for Oliver Hardy whose actual birthdate January 18th 1872. 
</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2011, Duketown. 
<p>Now that you are using this free module, why not make a donation to Duketown! Thanks in advance.
<form target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="AY8JBJZWU7Q7S">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
?>

==> BirthdayListing-1.4.zip: BirthdayListing/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Birthday Listing';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Thanks for using this module';
$lang['really_uninstall'] = 'Really? Are you sure you want to uninstall this module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module gives an overview of the person that are celebrating their birthday. Samples of celebrities 
are included. One is able to set when a person has deceased.';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';
$lang['error'] = 'Error!';
$lang['firstpage'] = '<<';
$lang['lastpage'] = '>>';
$lang['nextpage'] = '>';
$lang['title_pagelimit'] = 'Max lines/page in back end';
$lang['pagename'] = 'Page';
$lang['prevpage'] = '<';
$lang['prompt_of'] = 'of';
$lang['unlimited'] = 'Unlimited';

$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['addbirthday'] = 'Add birthday';
$lang['addtemplate'] = 'Add template';
$land['admin_title'] = 'Birthday Listing Admin Panel';
$lang['admindescription'] = 'Listing of the various birthdays. Samples of celebrities 
are included. One is able to set when a person has deceased.';
$lang['age'] = 'Age';
$lang['apply'] = 'Apply';
$lang['areyousure'] = 'Are you sure';
$lang['birthdate'] = 'Date of birth';
$lang['birthdates'] = 'Birth dates';
$lang['birthdayadded'] = 'Birthday added';
$lang['birthdaydeleted'] = 'Birthday deleted';
$lang['birthdayindays'] = 'Birthdays in the next %s days';
$lang['birthdays'] = 'Birthdays';
$lang['birthdayupdated'] = 'Birthday updated';
$lang['createsamples'] = 'Create samples';
$lang['deceased'] = 'Deceased on';
$lang['deceaseddates'] = 'Date of death';
$lang['deletesamples'] = 'Delete samples';
$lang['deletetemplate'] = 'Delete template';
$lang['edittemplate'] = 'Change';
$lang['errortemplatenameexists'] = 'Template name already exists';
$lang['help_template'] = 'Available parms are:<br />
- {$datetext} - Header text;<br />
- {$itemcount} - Number of birthdays found;<br />
- {$nobirthdays} - Message that there are no birthdays;<br />
- {$entry->age} - Age of person;<br />
- {$entry->birthday|date_format:"%Y %m %d"} - The actual date of birth and a format example;<br />
- {$entry->deceased|date_format:"%Y %m %d"} - The date person died;<br />
- {$entry->name} - Name of person;<br />
- {$entry->withindays} - Days until birthday;<br />
- {$entry->rowclass} - Contains for uneven rows: row1 and for even rows: row2 (which can be used in stylesheet).
';
$lang['isdead'] = 'Person has deceased';
$lang['orderbymonthday'] = 'Order by month/day';
$lang['orderbyname'] = 'Order by name';
$lang['postinstall'] = 'Be sure to set "Use Birthday Listings" permissions to use this module!';
$lang['name'] = 'Name of person';
$lang['names'] = 'Names';
$lang['nobirthdays'] = 'No birthdays today';
$lang['nobirthindays'] = 'No birthdays in the next %s days';
$lang['nobodybirthday'] = 'That is a pitty, nobody is celebrating their birthday!';
$lang['nonamegiven'] = 'Name is mandatory';
$lang['optionsupdated'] = 'Options are saved';
$lang['samplehandlingcreated'] = 'Samples have been created';
$lang['samplehandlingdeleted'] = 'Samples have been deleted';
$lang['template'] = 'Template';
$lang['template_help'] = 'Help for this Template';
$lang['template_deleted'] = 'Template deleted';
$lang['templatename'] = 'Name of template';
$lang['templatenametext'] = 'Templates';
$lang['templates'] = 'Templates';
$lang['title_birthdays'] = 'Birthdays';
$lang['title_birthdaysfound'] = 'Birthdays found';
$lang['title_dateformat'] = 'Date format for date picker';
$lang['title_nobirthdaystext'] = 'Text for front end when no birthdays';
$lang['title_options'] = 'Options';
$lang['title_orderbackend'] = 'Which order to list persons in backend';
$lang['title_splitdateused'] = 'Use drop down on date entry?';
$lang['title_templates'] = 'Templates';
$lang['todaysbirthdates'] = 'Today\'s birthdays:';
$lang['todaybirthdays'] = 'Today, %s persons turned a year older.';
$lang['updatetemplatesuccess'] = 'Template succefully saved';

// Parameters
$lang['helpshowage'] = 'Set to \'1\' to show the age of the person.';
$lang['helpshowdeceased'] = 'Set to \'1\' to show deceased person(s).';
$lang['helpsummarytemplate'] = 'Override to a template. If not used, template Summary will be taken.';
$lang['helpwithindays'] = 'Period of time in days to look for coming birthdays. Not including this parameter will show 
only todays birthdays.';

$lang['help'] = '<h3>What Does This Do?</h3>
<p>Gives an overview of the persons that are celebrating their birthday.</p>
<h3>How Do I Use It</h3>
<p>Just enter the persons with their date of birth and death and put the following as content in a page or template:
 {cms_module module=birthdaylisting}.<br />
An example with all the parameters is:<br />
{cms_module module=birthdaylisting showdeceased=1 showage=1 withindays=30}
  in which all the birthdays in the comming 30 days are shown (names, age, birthday and date of decease).<br />
The dates that are shown in the back end are formatted based upon the user preferences. If not available, \'%d %B %Y\' will be used.</p>
<p>
You can define the format of how you enter the birthday and date deceased via the options.
</p>
<p>Sample data can be prepared via the options tab. At least 5 days of each month will have a birthday of known and less known 
persons. When you enter birthdays yourself and after that you want to delete the sample data, your manually entered dates will remain while only 
the sample dates are removed.</p>
<p>Notes:
<ul>
 <li>you might find odd dates when sample data has been loaded. This is because the regularly used command (strftime) doesn\'t work 
correctly for dates dat are before 1900. Sorry for this. An example of this error might be seen
for Oliver Hardy whose actual birthdate January 18th 1872.</li>
 <li>Installing module JQueryTools allows you to sort the columns shown. However due to the 
 format of the shown dates, sorting the column birth date might not give the expected results. 
 In this case use the Age column to sort on. Only the contents of the current shown data is 
 sorted. Do you want to sort on all? Change the max lines per page setting on the Options tab.</li>
</ul>
</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2009-2013, Duketown. 
<p>Now that you are using this free module, why not make a donation to Duketown! Thanks in advance.
<form target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="AY8JBJZWU7Q7S">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
?>
